# -*- coding: utf-8 -*-
#
__version__ = '1.7.3'
__author__ = 'Nico Schlömer'
__author_email__ = 'nico.schloemer@gmail.com'
__website__ = 'https://github.com/nschloe/meshio'
__license__='License :: OSI Approved :: MIT License'
__status__='Development Status :: 5 - Production/Stable'
